module TravelWeights

! Non-mountain neighbors have the same weight
! So, if a coastal node has 2 land/coast and 2 sea neighbors
!   each each land/sea neigbor has a probability: (1-pe)/4
!   and the total sea travel probability is (1-pe)/2

use GlobalVariables
use LandTravel, only: HomogeneousLandTravel
use StraightLine, only: StraightLineSeaTravel
use ErrorHandling

implicit none

contains

! SetTravelWeights -> Used in MAIN

subroutine SetTravelWeights(seaTravelMode)
    !Sets the travel destinations and travel weigths according to the restrictions
    implicit none
    integer, intent(in) :: seaTravelMode
    integer :: i, landDest, totalDest !seaDest
    
    select case (seaTravelMode)
        case(0)  !No sea travel
            do i = 1, numHabitableNodes  !Checks all habitable nodes
                i_node = habitableNodes(i)
                Nodes(i_Node)%destinationWeight = 0
                Nodes(i_Node)%destinations = 0
                totalDest = Nodes(i_node)%land_sea(1)
                call HomogeneousLandTravel(i_node, totalDest, totalDest)         
            enddo
        case(1)  !Straight Line Sea Travel
            do i = 1, numHabitableNodes  !Checks all habitable nodes
                i_node = habitableNodes(i)
                Nodes(i_Node)%destinationWeight = 0
                Nodes(i_Node)%destinations = 0
                landDest = Nodes(i_node)%land_sea(1)
                
                if (Nodes(i_node)%node_type == 1) then    
                    call HomogeneousLandTravel(i_node, landDest, landDest)         
                else if (Nodes(i_node)%node_type == 3) then
                    totalDest = landDest + Nodes(i_node)%land_sea(2)
                    call HomogeneousLandTravel(i_node, landDest, totalDest)         
                    call StraightLineSeaTravel(i_node)
                else
                    print*, "Node", i_node, "should not be in the list of habitable nodes"
                    stop
                endif
            enddo
        case default
            call InputError("Sea travel mode not defined")
    end select

end subroutine SetTravelWeights

end module TravelWeights